mapGrid2D_improvements {#master}
-----------------------

### yarp::dev
* `mapGrid2D` Improved logic to convert ros map images to ros occupancy data and viceversa

### harness_dev
* added new tests to `MapGrid2DTest.cpp` to verify the load/save methods

### examples
*  added `rosmap_publisher` to ros examples

